Player Class (pysqueezecenter.player.Player) — PySqueezeCenter v0.93 documentation

### Navigation

- index
- next |
- previous |
- PySqueezeCenter v0.93 documentation »

# Player Class (pysqueezecenter.player.Player)

The Player class allows individual control of any Logitech SqueezeCenter compatible devices that are connected and registered with the SqueezeCenter server.

Any function calls made by the Player are communicated to the SqueezeCenter Telnet server via the parent Server (pysqueezecenter.server.Server) class.

class `pysqueezecenter.player.` `Player`(server=None, index=None, update=True)

  SqueezeCenter Player

  `bass_down`(amount=5)

    Decrease Player Bass

  `bass_up`(amount=5)

    Increase Player Bass

  `display`(line1='', line2='', duration=3)
  `forward`(seconds=10)

    Seek Player Forward

  `get_bass`()

    Get Player Bass

  `get_display_type`()

    Get Player Display Type String

  `get_ip_address`()

    Get Player IP Address

  `get_ir_state`()

    Get Player Infrared State

  `get_mode`()

    Get Player Mode

  `get_model`()

    Get Player Model String

  `get_muting`()

    Get Player Muting Status

  `get_name`()

    Get Player Name

  `get_pitch`()

    Get Player Pitch

  `get_power_state`()

    Get Player Power State

  `get_pref_value`(name, namespace=None)

    Get Player Preference Value

  `get_rate`()

    Get Player Rate

  `get_ref`()

    Get Player Ref

  `get_time_elapsed`()

    Get Player Time Elapsed

  `get_time_remaining`()

    Get Player Time Remaining

  `get_track_album`()

    Get Players Current Track Album

  `get_track_artist`()

    Get Players Current Track Artist

  `get_track_current_title`()

    Get Players Current Track Current Title

  `get_track_duration`()

    Get Players Current Track Duration

  `get_track_genre`()

    Get Players Current Track Genre

  `get_track_path`()

    Get Players Current Track Path

  `get_track_remote`()

    Is Players Current Track Remotely Hosted?

  `get_track_title`()

    Get Players Current Track Title

  `get_treble`()

    Get Player Treble

  `get_uuid`()

    Get Player UUID

  `get_volume`()

    Get Player Volume

  `get_wifi_signal_strength`()

    Get Player WiFi Signal Strength

  `has_permission`(request_terms)

    Check Player User Permissions

  `ir_button`(button)

    Simulate IR Button Press

  `mute`()

    Mute Player

  `next`()

    Next Track

  `pause`()

    Pause On

  `pitch_down`(amount=5)

    Decrease Player Pitch

  `pitch_up`(amount=5)

    Increase Player Pitch

  `play`()

    Play

  `playlist_add`(item)

    Add Item To Playlist

  `playlist_clear`()

    Clear the entire playlist. Will stop the player.

  `playlist_delete`(item)

    Delete Item From Playlist By Name

  `playlist_erase`(index)

    Erase Item From Playlist

  `playlist_get_info`()

    Get info about the tracks in the current playlist

  `playlist_insert`(item)

    Insert Item Into Playlist (After Current Track)

  `playlist_move`(from_index, to_index)

    Move Item In Playlist

  `playlist_play`(item)

    Play Item Immediately

  `playlist_play_index`(index)

    Play track at a certain position in the current playlist (index is zero-based)

  `playlist_track_count`()

    Get the amount of tracks in the current playlist

  `prev`()

    Previous Track

  `rate_down`(amount=1)

    Decrease Player Rate

  `rate_up`(amount=1)

    Increase Player Rate

  `request`(command_string, preserve_encoding=False)

    Executes Telnet Request via SqueezeCenter

  `rewind`(seconds=10)

    Seek Player Backwards

  `seek_to`(seconds)

    Seek Player

  `set_bass`(bass)

    Set Player Bass

  `set_ir_state`(state)

    Set Player Power State

  `set_muting`(state)

    Set Player Muting Status

  `set_name`(name)

    Set Player Name

  `set_pitch`(pitch)

    Set Player Pitch

  `set_power_state`(state)

    Set Player Power State

  `set_pref_value`(name, value, namespace=None)

    Set Player Preference Value

  `set_rate`(rate)

    Set Player Rate

  `set_treble`(treble)

    Set Player Treble

  `set_volume`(volume)

    Set Player Volume

  `show`(line1='', line2='', duration=3, brightness=4, font='standard', centered=False)

    Displays text on Player display

  `stop`()

    Stop

  `toggle`()

    Play/Pause Toggle

  `treble_down`(amount=5)

    Decrease Player Treble

  `treble_up`(amount=5)

    Increase Player Treble

  `unmute`()

    Unmute Player

  `unpause`()

    Pause Off

  `update`(index, update=True)

    Update Player Properties from SqueezeCenter

  `volume_down`(amount=5)

    Decrease Player Volume

  `volume_up`(amount=5)

    Increase Player Volume

### Navigation

- index
- next |
- previous |
- PySqueezeCenter v0.93 documentation »